@@ -1,5 +1,3 @@
-
-import urllib.parse
 import requests
 import posixpath
 import logging
@@ -33,7 +31,6 @@ def get_jwks():
         raise presalytics.lib.exceptions.ApiError(message="Could not get jwks from Uri", status_code=r.status_code)
 
 
-
 class OidcClient(object):
     """
     A helper class for negotiating tokens from an oidc provider, defalting to https://login.presalytics.io
@@ -57,6 +54,7 @@ class OidcClient(object):
 
 
     """
+
     def __init__(self, client_id=None, client_secret=None, validate_tokens=True, *args, **kwargs):
         self.auth_host = kwargs.get("auth_host", cnst.OIDC_AUTH_HOST)
         self.well_known_endpoint = posixpath.join(self.auth_host, kwargs.get("well_known_path", ".well-known/openid-configuration"))
@@ -75,6 +73,53 @@ class OidcClient(object):
             "slow_down"
         ]
 
+    def handle_device_code_response(self, device_code_response):
+        user_code_message = "This device's user code is: {}.  Please verify this code when logging in.".format(device_code_response["user_code"])
+        print(user_code_message)
+        cli_message = "Please open a webrowser to {0} and login.".format(device_code_response["verification_uri_complete"])
+        print(cli_message)
+        try:
+            webbrowser.open_new_tab(device_code_response["verification_uri_complete"])
+        except BaseException:
+            pass
+
+    def poll_for_token(self, device_code_response):
+        sleep_interval = device_code_response["interval"]
+        auth_data = {
+            "grant_type": "urn:ietf:params:oauth:grant-type:device_code",
+            "device_code": device_code_response["device_code"],
+            "client_id": self.client_id
+        }
+        headers = {
+            'content-type': 'application/x-www-form-urlencoded'
+        }
+        repoll = True
+        while repoll:
+            token_response = requests.post(self.token_endpoint, auth_data, headers=headers)
+            if token_response.status_code != 200:
+                err_resp = token_response.json()
+                err_msg = err_resp["error"]
+                if err_msg in self.repoll_errors:
+                    time.sleep(sleep_interval)
+                    if err_msg == "slow_down":
+                        time.sleep(sleep_interval)
+                    logger.debug("User has not yet logged in.  Repolling...")
+                else:
+                    message = "Error: {0} -- {1}".format(err_msg, err_resp["error_description"])
+                    raise presalytics.lib.exceptions.ApiError(message=message, status_code=token_response.status_code)
+            else:
+                repoll = False
+        token_data = token_response.json()
+        if token_data.get('access_token', None):
+            print("Login Success! Please continue with your work.")
+            logger.debug("User logged in successfully.")
+        else:
+            message = "Error: {0} -- {1}".format(err_msg, err_resp["error_description"])
+            raise presalytics.lib.exceptions.ApiError(message=message, status_code=token_response.status_code)
+        if self.validate_tokens:
+            self.validate_token(token_data["access_token"])
+        return token_data
+
     def token(self, username, password=None, audience=None, scope=None, **kwargs) -> typing.Dict:
         """
         Get an access token
@@ -84,7 +129,7 @@ class OidcClient(object):
         if not audience:
             audience = self.audience
         if password and self.client_secret:
-            #use password grant if present (not recommended)
+            # use password grant if present (not recommended)
             data = {
                 "grant_type": "password",
                 "username": username,
@@ -95,7 +140,7 @@ class OidcClient(object):
                 "scope": scope
             }
             token_data = self._post(self.token_endpoint, data)
-            
+
         else:
             # Use device grant as default
             device_data = {
@@ -105,48 +150,8 @@ class OidcClient(object):
             }
 
             device_code_response = self._post(self.device_endpoint, device_data)
-            user_code_message = "This device's user code is: {}.  Please verify this code when logging in.".format(device_code_response["user_code"])
-            print(user_code_message)
-            cli_message = "Please open a webrowser to {0} and login.".format(device_code_response["verification_uri_complete"])
-            print(cli_message)
-            try:
-                webbrowser.open_new_tab(device_code_response["verification_uri_complete"])
-            except:
-                pass
-            sleep_interval = device_code_response["interval"]
-            auth_data = {
-                "grant_type": "urn:ietf:params:oauth:grant-type:device_code",
-                "device_code": device_code_response["device_code"],
-                "client_id": self.client_id
-            }
-            headers = {
-                'content-type': 'application/x-www-form-urlencoded'
-            }
-            repoll = True
-            while repoll:
-                token_response = requests.post(self.token_endpoint, auth_data, headers=headers)
-                if token_response.status_code != 200:
-                    err_resp = token_response.json()
-                    err_msg = err_resp["error"]
-                    if err_msg in self.repoll_errors:
-                        time.sleep(sleep_interval)
-                        if err_msg == "slow_down":
-                            time.sleep(sleep_interval)
-                        logger.debug("User has not yet logged in.  Repolling...")                     
-                    else:
-                        message = "Error: {0} -- {1}".format(err_msg, err_resp["error_description"])
-                        raise presalytics.lib.exceptions.ApiError(message=message, status_code=token_response.status_code)
-                else:
-                    repoll = False
-            token_data = token_response.json()
-            if token_data.get('access_token', None):
-                print("Login Success! Please continue with your work.")
-                logger.debug("User logged in successfully.")
-            else:
-                message = "Error: {0} -- {1}".format(err_msg, err_resp["error_description"])
-                raise presalytics.lib.exceptions.ApiError(message=message, status_code=token_response.status_code)
-        if self.validate_tokens:
-            self.validate_token(token_data["access_token"])
+            self.handle_device_code_response(device_code_response)
+            token_data = self.poll_for_token(device_code_response)
         return token_data
 
     def validate_token(self, token):
@@ -182,10 +187,8 @@ class OidcClient(object):
                 raise presalytics.lib.exceptions.ApiError(message="invalid token (likely malformed)", status_code=401)
             logger.debug("Access token validated.")
             return payload
-        
-        raise presalytics.lib.exceptions.ApiError(message="invalid_header: could not find key in jwks",status_code=401)
-        
 
+        raise presalytics.lib.exceptions.ApiError(message="invalid_header: could not find key in jwks", status_code=401)
 
     def refresh_token(self, refresh_token, scope=None):
         """
@@ -205,7 +208,7 @@ class OidcClient(object):
         }
 
         token_data = self._post(self.token_endpoint, data)
-        
+
         if self.validate_tokens:
             self.validate_token(token_data["access_token"])
         return token_data
@@ -221,7 +224,6 @@ class OidcClient(object):
 
         return self._handle_response(response)
 
-
     def _handle_response(self, response):
         if response.status_code == 401:
             raise presalytics.lib.exceptions.ApiError(message="Unauthorized", status_code=401)
@@ -251,7 +253,7 @@ class OidcClient(object):
                 except Exception:
                     pass
         return data
-    
+
     def client_credentials_token(self, audience=None, scope=None):
         if not self.client_secret:
             raise presalytics.lib.exceptions.ApiError(message="Must have client secret for client credentials grant", status_code=400)
@@ -270,13 +272,3 @@ class OidcClient(object):
     def get_user_id(self, token) -> str:
         payload = presalytics.client.oidc.OidcClient().validate_token(token)
         return payload.get('https://api.presalytics.io/api_user_id', None)
-
-    
-        
-
-
-        
-
-
-
-        
\ No newline at end of file
