@@ -25,7 +25,7 @@ class PluginBase(abc.ABC):
     ----------
 
     __plugin_kind__ : str
-        The __plugin_kind__ is a static string that instructs classes 
+        The __plugin_kind__ is a static string that instructs classes
         the render story outlines (e.g., presalytics.story.revealer.Revealer) where
         to where render the plugin (i.e., at the bottom of the html body for scripts).
 
@@ -36,7 +36,7 @@ class PluginBase(abc.ABC):
     __dependencies__ : list of dict
         A list of plugs that should be rendered above this plugin in an html document.  This ensures
         the needed javascript or css is loaded prior user's plugin runs.
-        
+
         For example, if a user creates plugin requires d3.js to function, dependencies should include
         the following configuration:
 
@@ -98,7 +98,7 @@ class PluginBase(abc.ABC):
 
 class ScriptPlugin(PluginBase):
     """
-    A script plugin incorporates whitelisted or local `<script>` tags into a 
+    A script plugin incorporates whitelisted or local `<script>` tags into a
     rendered story
     """
     __plugin_kind__ = 'script'
@@ -167,6 +167,7 @@ class PluginRegistry(presalytics.lib.registry.RegistryBase):
     """
     The Plugin Registry class
     """
+
     def __init__(self, **kwargs):
         super(PluginRegistry, self).__init__(**kwargs)
 
@@ -176,6 +177,9 @@ class PluginRegistry(presalytics.lib.registry.RegistryBase):
     def get_type(self, klass):
         return getattr(klass, "__plugin_kind__", None)
 
+    def get_settings_object(self):
+        return presalytics.settings.PLUGINS
+
 
 class Graph():
     """
@@ -183,6 +187,7 @@ class Graph():
 
     Adapted from https://www.geeksforgeeks.org/detect-cycle-in-a-graph/
     """
+
     def __init__(self, vertices):
         self.graph = collections.defaultdict(list)
         self.V = vertices
@@ -331,7 +336,7 @@ class PluginManager(object):
                 except Exception as ex:
                     logger.exception(ex)
                     t, v, tb = sys.exc_info()
-                    if not presalytics.CONFIG.get("DEBUG", False):
+                    if not presalytics.settings.DEBUG:
                         div = presalytics.lib.exceptions.RenderExceptionHandler(ex, "plugin", traceback=tb).render_exception()
                         template = lxml.html.Element('template')
                         template.extend(list(lxml.html.fragment_fromstring(div)))
@@ -345,7 +350,7 @@ class PluginManager(object):
     def get_plugins_from_nested_dict(source_dict: typing.Dict, plugin_list: typing.List[typing.Dict] = None) -> typing.List[typing.Dict]:
         if not plugin_list:
             plugin_list = []
-    
+
         for key, val in source_dict.items():
             if key == "plugins":
                 if isinstance(val, list):
